# kzutil

kzutil is a library that gives you useful util.

- HomePage: https://github.com/kzhu2099/KZ-Util
- Issues: https://github.com/kzhu2099/KZ-Util/issues

[![PyPI Downloads](https://static.pepy.tech/badge/kzutil)](https://pepy.tech/projects/kzutil)

Author: Kevin Zhu

## Features

- funcs to use
- consts to use
- updating frequently based on need

## Installation

To install kzutil, use pip: ```pip install kzutil```.

However, many prefer to use a virtual environment.

macOS / Linux:

```sh
# make your desired directory
mkdir /path/to/your/directory
cd /path/to/your/directory

# setup the .venv (or whatever you want to name it)
pip install virtualenv
python3 -m venv .venv

# install kzutil
source .venv/bin/activate
pip install kzutil

deactivate # when you are completely done
```

Windows CMD:

```sh
# make your desired directory
mkdir C:path\to\your\directory
cd C:path\to\your\directory

# setup the .venv (or whatever you want to name it)
pip install virtualenv
python3 -m venv .venv

# install kzutil
.venv\Scripts\activate
pip install kzutil

deactivate # when you are completely done
```